@@ -4,7 +4,7 @@
  * Gnome Crystal
  * dialog.h 
  *
- * Copyright (C) 2001-2003
+ * Copyright (C) 2001-2004
  *
  * Developed by Jean Brfort <jean.brefort@ac-dijon.fr>
  *
@@ -55,11 +55,11 @@ static void on_help(GtkWidget* widget, gcDialog* dialog)
 	dialog->Help();
 }
 
-gcDialog::gcDialog(const char* filename, const char* windowname, const char* helpfile)
+gcDialog::gcDialog(const char* filename, const char* windowname)
 {
 	xml =  glade_xml_new(filename, windowname, NULL);
 	if (xml)  glade_xml_signal_autoconnect (xml);
-	dialog = GTK_WINDOW(glade_xml_get_widget(xml, windowname));
+	dialog = GTK_WINDOW(glade_xml_get_widget(xml, m_WindowName = windowname));
 	g_signal_connect(G_OBJECT(dialog), "destroy", GTK_SIGNAL_FUNC(on_destroy), this);
 	GtkWidget* button = glade_xml_get_widget(xml, "OK");
 	if (button) g_signal_connect(G_OBJECT(button), "clicked", GTK_SIGNAL_FUNC(on_OK), this);
@@ -69,14 +69,11 @@ gcDialog::gcDialog(const char* filename, const char* windowname, const char* hel
 	if (button) g_signal_connect(G_OBJECT(button), "clicked", GTK_SIGNAL_FUNC(on_cancel), this);
 	button = glade_xml_get_widget(xml, "help");
 	if (button) g_signal_connect(G_OBJECT(button), "clicked", GTK_SIGNAL_FUNC(on_help), this);
-	if (helpfile) m_HelpFile = g_strdup(helpfile);
-	else m_HelpFile = NULL;
 	notebook = (GtkNotebook*)glade_xml_get_widget(xml, "notebook");
 }
 
 gcDialog::~gcDialog()
 {
-	if (m_HelpFile) g_free(m_HelpFile);
 }
 
 void gcDialog::Destroy()
@@ -88,30 +85,9 @@ bool gcDialog::Apply() {}
 
 void gcDialog::Help()
 {
-	gchar* tag = NULL;
-	if (notebook)
-	{
-		int i = gtk_notebook_get_current_page(notebook);
-		GtkWidget* w = gtk_notebook_get_nth_page(notebook, i);
-		const gchar* name = gtk_widget_get_name(w);
-		tag = g_ascii_strup(name, strlen(name));
-	}
-	gchar* helpfile = NULL/* = (m_HelpFile) ? gnome_help_file_find_file("gcrystal", m_HelpFile) : gnome_help_file_find_file("gcrystal", "index.html")*/;
-	if (helpfile != NULL)
-	{
-		gchar* url = (tag) ? g_strconcat("ghelp:", helpfile, "#", tag, NULL) : g_strconcat("ghelp:", helpfile, NULL);
-//		gnome_help_goto(NULL, url);
-		g_free(url);
-//		g_free(helpfile);
-	}
-	else
-	{
-		gchar *str = g_strdup_printf(_("Couldn't find help file :\n%s"), helpfile);
-		GtkWidget* message = gtk_message_dialog_new(NULL, (GtkDialogFlags) 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, str);
-		g_signal_connect_swapped (G_OBJECT (message), "response", G_CALLBACK (gtk_widget_destroy), G_OBJECT (message));
-		gtk_widget_show(message);
-		g_free(str);
-	}
+	gchar *tag = g_strdup_printf("%s-%s", PACKAGE, m_WindowName);
+	
+	gnome_help_display(PACKAGE, tag, NULL);
 	g_free(tag);
 }
 
